isFirstLaunch property

bool get isFirstLaunch

Whether the current installation run is the first launch observed by the SDK.

This value is restored during init and stays stable for the current app session.

Implementation

bool get isFirstLaunch => _runtime.isFirstLaunch;