AttriaxCreateDynamicLinkResult class
Constructors
- AttriaxCreateDynamicLinkResult({required AttriaxDynamicLinkRecord link, String? requestVersion, DateTime? acceptedAt})
-
const
-
AttriaxCreateDynamicLinkResult.fromJson(Map<
String, Object?> json) -
factory
Properties
- acceptedAt → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- link → AttriaxDynamicLinkRecord
-
final
- requestVersion → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited