AttriaxSynchronization class

Synchronization state exposed from the public Attriax SDK.

Constructors

AttriaxSynchronization(AttriaxRuntimeInterface _runtime)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isSynchronized bool
Whether every queued SDK request has been delivered successfully.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state AttriaxSynchronizationState
Current runtime synchronization state.
no setter
states Stream<AttriaxSynchronizationState>
Broadcast synchronization state stream with no buffering.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited