AttriaxTracking class

Tracking, revenue, token-registration, and user helpers exposed by Attriax.

Properties

anonymousTrackingEnabled bool
Whether GDPR-safe anonymous tracking is currently allowed.
getter/setter pair
enabled bool
Whether event-style tracking is currently enabled.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearUserProperties({List<String>? propertyNames}) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recordAdEvent(AttriaxAdEventType type, {String? adNetwork, String? mediationNetwork, String? adUnitId, String? adPlacement, String? adFormat, String? adType, String? failureReason, num? loadLatencyMs, String? rewardType, num? rewardAmount, bool? test, Map<String, Object?>? metadata, bool flushImmediately = true}) → void
recordAdRevenue({required num revenue, String currency = 'USD', bool revenueInMicros = false, String? adNetwork, String? adFormat, String? adType, String? adPlacement, bool? test, Map<String, Object?>? metadata, bool flushImmediately = true}) → void
recordError(Object error, StackTrace stackTrace, {bool fatal = false, String source = 'manual', String? reason, Map<String, Object?>? metadata}) → void
recordEvent(String eventName, {Map<String, Object?>? eventData, bool flushImmediately = false}) → void
recordNotification({required AttriaxNotificationEventType type, required String notificationId, String? linkId, String? campaignId, String? title, AttriaxNotificationEventSource? source, Map<String, Object?>? payload, Map<String, Object?>? metadata, bool flushImmediately = false}) → void
Records a push-notification lifecycle event for attribution.
recordNotificationDismissed({required String notificationId, String? linkId, String? campaignId, String? title, AttriaxNotificationEventSource? source, Map<String, Object?>? payload, Map<String, Object?>? metadata, bool flushImmediately = false}) → void
Records that a push notification was dismissed without opening.
recordNotificationOpened({required String notificationId, String? linkId, String? campaignId, String? title, AttriaxNotificationEventSource? source, Map<String, Object?>? payload, Map<String, Object?>? metadata, bool flushImmediately = false}) → void
Records that a push notification was opened (tapped).
recordNotificationReceived({required String notificationId, String? linkId, String? campaignId, String? title, AttriaxNotificationEventSource? source, Map<String, Object?>? payload, Map<String, Object?>? metadata, bool flushImmediately = false}) → void
Records that a push notification was received / displayed.
recordPageView(String pageName, {String? pageClass, String? pageTitle, String? previousPageName, Map<String, Object?>? parameters, String source = 'manual', bool flushImmediately = false}) → void
recordPurchase({required num revenue, String currency = 'USD', bool revenueInMicros = false, String? purchaseType, String? productId, String? transactionId, String? originalTransactionId, String? validationProvider, String? validationEnvironment, String? purchaseToken, String? receiptData, String? signedPayload, String? receiptSignature, bool? isRenewal, int quantity = 1, String? store, String? packageName, bool? voided, bool? test, String? validationId, Map<String, Object?>? metadata, bool flushImmediately = true}) → void
recordRefund({required num revenue, String currency = 'USD', bool revenueInMicros = false, String? purchaseType, String? productId, String? transactionId, String? originalTransactionId, int quantity = 1, String? store, String? packageName, bool? voided, bool? test, String? reason, Map<String, Object?>? metadata, bool flushImmediately = true}) → void
registerApplePushToken(String? token, {Map<String, Object?>? metadata}) Future<void>
registerFirebaseMessagingToken(String? token, {Map<String, Object?>? metadata}) Future<void>
setUser(String? userId, {String? userName}) → void
setUserProperties(Map<String, Object?> properties) → void
setUserProperty(String name, Object? value) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited