AttributionType enum

Attribution classification returned by Attriax.

Inheritance
Available extensions

Values

referrer → const AttributionType

Attribution derived from platform install-referrer data.

fingerprint → const AttributionType

Attribution derived from probabilistic fingerprint matching.

external → const AttributionType

Attribution derived from external provider resolutions.

organic → const AttributionType

Attribution assigned when no attributable source was found.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AttributionType>
A constant List of the values in this enum, in order of their declaration.